@@ -182,6 +182,17 @@ bot = create(bot_filter)
 """Filter messages coming from bots."""
 
 
+# endregion
+
+# region sender_chat_filter
+async def sender_chat_filter(_, __, m: Message):
+    return bool(m.sender_chat)
+
+
+sender_chat = create(sender_chat_filter)
+"""Filter messages coming from sender chat."""
+
+
 # endregion
 
 # region incoming_filter
@@ -219,11 +230,11 @@ text = create(text_filter)
 
 # region reply_filter
 async def reply_filter(_, __, m: Message):
-    return bool(m.reply_to_message_id)
+    return bool(m.reply_to_message_id or m.reply_to_story_id)
 
 
 reply = create(reply_filter)
-"""Filter messages that are replies to other messages."""
+"""Filter messages that are replies to other messages or stories."""
 
 
 # endregion
@@ -315,6 +326,50 @@ game = create(game_filter)
 """Filter messages that contain :obj:`~pyrogram.types.Game` objects."""
 
 
+# endregion
+
+# region giveaway_filter
+async def giveaway_filter(_, __, m: Message):
+    return bool(m.giveaway)
+
+
+giveaway = create(giveaway_filter)
+"""Filter messages that contain :obj:`~pyrogram.types.Giveaway` objects."""
+
+
+# endregion
+
+# region giveaway_result_filter
+async def giveaway_result_filter(_, __, m: Message):
+    return bool(m.giveaway_result)
+
+
+giveaway_result = create(giveaway_result_filter)
+"""Filter messages that contain :obj:`~pyrogram.types.GiveawayResult` objects."""
+
+
+# endregion
+
+# region gift_code_filter
+async def gift_code_filter(_, __, m: Message):
+    return bool(m.gift_code)
+
+
+gift_code = create(gift_code_filter)
+"""Filter messages that contain :obj:`~pyrogram.types.GiftCode` objects."""
+
+
+# endregion
+
+# region requested_chats_filter
+async def requested_chats_filter(_, __, m: Message):
+    return bool(m.requested_chats)
+
+
+requested_chats = create(requested_chats_filter)
+"""Filter service messages for request chats."""
+
+
 # endregion
 
 # region video_filter
@@ -424,6 +479,7 @@ async def dice_filter(_, __, m: Message):
 dice = create(dice_filter)
 """Filter messages that contain :obj:`~pyrogram.types.Dice` objects."""
 
+
 # endregion
 
 # region quote_filter
@@ -434,6 +490,7 @@ async def quote_filter(_, __, m: Message):
 quote = create(quote_filter)
 """Filter quote messages."""
 
+
 # endregion
 
 # region media_spoiler
@@ -448,9 +505,8 @@ media_spoiler = create(media_spoiler_filter)
 # endregion
 
 # region private_filter
-async def private_filter(_, __, u: Update):
-    m = u.message if isinstance(u, CallbackQuery) else u
-    return bool(m and m.chat and m.chat.type in {enums.ChatType.PRIVATE, enums.ChatType.BOT})
+async def private_filter(_, __, m: Message):
+    return bool(m.chat and m.chat.type in {enums.ChatType.PRIVATE, enums.ChatType.BOT})
 
 
 private = create(private_filter)
@@ -460,9 +516,8 @@ private = create(private_filter)
 # endregion
 
 # region group_filter
-async def group_filter(_, __, u: Update):
-    m = u.message if isinstance(u, CallbackQuery) else u
-    return bool(m and m.chat and m.chat.type in {enums.ChatType.GROUP, enums.ChatType.SUPERGROUP})
+async def group_filter(_, __, m: Message):
+    return bool(m.chat and m.chat.type in {enums.ChatType.GROUP, enums.ChatType.SUPERGROUP})
 
 
 group = create(group_filter)
@@ -472,15 +527,36 @@ group = create(group_filter)
 # endregion
 
 # region channel_filter
-async def channel_filter(_, __, u: Update):
-    m = u.message if isinstance(u, CallbackQuery) else u
-    return bool(m and m.chat and m.chat.type == enums.ChatType.CHANNEL)
+async def channel_filter(_, __, m: Message):
+    return bool(m.chat and m.chat.type == enums.ChatType.CHANNEL)
 
 
 channel = create(channel_filter)
 """Filter messages sent in channels."""
 
 
+# endregion
+
+# region forum_filter
+async def forum_filter(_, __, m: Message):
+    return bool(m.chat and m.chat.is_forum)
+
+
+forum = create(forum_filter)
+"""Filter messages sent in forums."""
+
+
+# endregion
+
+# region story_filter
+async def story_filter(_, __, m: Message):
+    return bool(m.story)
+
+
+story = create(story_filter)
+"""Filter messages that contain :obj:`~pyrogram.types.Story` objects."""
+
+
 # endregion
 
 # region new_chat_members_filter
@@ -657,6 +733,17 @@ via_bot = create(via_bot_filter)
 """Filter messages sent via inline bots"""
 
 
+# endregion
+
+# region admin_filter
+async def admin_filter(_, __, m: Message):
+    return bool(m.chat and m.chat.is_admin)
+
+
+admin = create(admin_filter)
+"""Filter chats where you have admin rights"""
+
+
 # endregion
 
 # region video_chat_started_filter
