@@ -42,11 +42,14 @@ class SendVoice:
         disable_notification: bool = None,
         message_thread_id: int = None,
         reply_to_message_id: int = None,
+        reply_to_chat_id: Union[int, str] = None,
         reply_to_story_id: int = None,
         quote_text: str = None,
         quote_entities: List["types.MessageEntity"] = None,
+        quote_offset: int = None,
         schedule_date: datetime = None,
         protect_content: bool = None,
+        view_once: bool = None,
         reply_markup: Union[
             "types.InlineKeyboardMarkup",
             "types.ReplyKeyboardMarkup",
@@ -92,25 +95,36 @@ class SendVoice:
 
             message_thread_id (``int``, *optional*):
                 Unique identifier for the target message thread (topic) of the forum.
-                for forum supergroups only.
+                For supergroups only.
 
             reply_to_message_id (``int``, *optional*):
                 If the message is a reply, ID of the original message
 
+            reply_to_chat_id (``int``, *optional*):
+                If the message is a reply, ID of the original chat.
+
             reply_to_story_id (``int``, *optional*):
                 Unique identifier for the target story.
 
-            quote_text (``str``):
+            quote_text (``str``, *optional*):
                 Text of the quote to be sent.
 
-            quote_entities (List of :obj:`~pyrogram.types.MessageEntity`):
+            quote_entities (List of :obj:`~pyrogram.types.MessageEntity`, *optional*):
                 List of special entities that appear in quote text, which can be specified instead of *parse_mode*.
+
+            quote_offset (``int``, *optional*):
+                Offset for quote in original message.
+
             schedule_date (:py:obj:`~datetime.datetime`, *optional*):
                 Date when the message will be automatically sent.
 
             protect_content (``bool``, *optional*):
                 Protects the contents of the sent message from forwarding and saving.
 
+            view_once (``bool``, *optional*):
+                Self-Destruct Timer.
+                If True, the voice note will self-destruct after it was listened.
+
             reply_markup (:obj:`~pyrogram.types.InlineKeyboardMarkup` | :obj:`~pyrogram.types.ReplyKeyboardMarkup` | :obj:`~pyrogram.types.ReplyKeyboardRemove` | :obj:`~pyrogram.types.ForceReply`, *optional*):
                 Additional interface options. An object for an inline keyboard, custom reply keyboard,
                 instructions to remove reply keyboard or to force a reply from the user.
@@ -152,22 +166,29 @@ class SendVoice:
 
                 # Set voice note duration
                 await app.send_voice("me", "voice.ogg", duration=20)
+
+                # Send self-destructing voice note
+                await app.send_voice("me", "voice.ogg", ttl_seconds=(1 << 31) - 1)
         """
         file = None
 
         try:
             if isinstance(voice, str):
                 if os.path.isfile(voice):
+                    mime_type = self.guess_mime_type(voice) or "audio/ogg"
+                    if mime_type == "audio/mpeg":
+                        mime_type = "audio/ogg"
                     file = await self.save_file(voice, progress=progress, progress_args=progress_args)
                     media = raw.types.InputMediaUploadedDocument(
-                        mime_type=self.guess_mime_type(voice) or "audio/mpeg",
+                        mime_type=mime_type,
                         file=file,
                         attributes=[
                             raw.types.DocumentAttributeAudio(
                                 voice=True,
                                 duration=duration
                             )
-                        ]
+                        ],
+                        ttl_seconds=(1 << 31) - 1 if view_once else None
                     )
                 elif re.match("^https?://", voice):
                     media = raw.types.InputMediaDocumentExternal(
@@ -176,16 +197,20 @@ class SendVoice:
                 else:
                     media = utils.get_input_media_from_file_id(voice, FileType.VOICE)
             else:
+                mime_type = self.guess_mime_type(voice.name) or "audio/ogg"
+                if mime_type == "audio/mpeg":
+                    mime_type = "audio/ogg"
                 file = await self.save_file(voice, progress=progress, progress_args=progress_args)
                 media = raw.types.InputMediaUploadedDocument(
-                    mime_type=self.guess_mime_type(voice.name) or "audio/mpeg",
+                    mime_type=mime_type,
                     file=file,
                     attributes=[
                         raw.types.DocumentAttributeAudio(
                             voice=True,
                             duration=duration
                         )
-                    ]
+                    ],
+                    ttl_seconds=(1 << 31) - 1 if view_once else None
                 )
 
             quote_text, quote_entities = (await utils.parse_text_entities(self, quote_text, parse_mode, quote_entities)).values()
@@ -201,10 +226,11 @@ class SendVoice:
                             reply_to=utils.get_reply_to(
                                 reply_to_message_id=reply_to_message_id,
                                 message_thread_id=message_thread_id,
-                                reply_to_peer=peer,
+                                reply_to_peer=await self.resolve_peer(reply_to_chat_id) if reply_to_chat_id else None,
                                 reply_to_story_id=reply_to_story_id,
                                 quote_text=quote_text,
                                 quote_entities=quote_entities,
+                                quote_offset=quote_offset,
                             ),
                             random_id=self.rnd_id(),
                             schedule_date=utils.datetime_to_timestamp(schedule_date),
